<a href="{{ url }}" class="nav-link">
    <span class="btn btn-{{ btn_modifier }} d-none d-lg-inline-block">
        <i class="{{ fa_icon }} fa-fw me-2"></i>
        {{ title }}
    </span>

    <span class="d-inline-block d-lg-none">
        <i class="{{ fa_icon }} fa-fw me-2"></i>
        {{ title }}
    </span>
</a>
